# django-amahapp

Un package Django pour enregistrer automatiquement les activités des utilisateurs :
- Pages visitées
- Adresse IP
- Navigateur utilisé
- Durée de la requête

## Installation

```bash
pip install django-amahapp
